# Mdformat yamlfmt

Mdformat plugin to format yaml code blocks using [yamlfmt](https://github.com/google/yamlfmt).

## Installation

The package is available on PyPI [here](https://pypi.org/project/mdformat-yamlfmt/), you can install it with:

```bash
pip install mdformat-yamlfmt
```
